import React, { Component } from 'react'
import PropTypes from 'prop-types'
import { TextField, Select, MenuItem } from '@material-ui/core'
import { Field, Form, Store } from '../src'
import RButton from './components/RaisedButtonComponent'
import styles from './styles.icss'

//	Set validations for various fields
const validations = {
	emailAddress: {
		presence: true,
		email: true
	},
	mobile: {
		presence: true,
		numericality: 'onlyInteger',
		length: {
			minimum: 10
		}
	},
	shipSpeed: {
		presence: true
	},
	inputty: {
		presence: true,
		length: {
			minimum: 4
		}
	}
}

//	Custom input box, with ability to show error message
/* eslint-disable react/no-multi-comp */
class InputComponent extends Component {
	render() {
		//	We extract the helperText and error props, so that the input doesn't receive them
		const { helperText, error, ...rest } = this.props

		return (<div style={{ margin: '1rem 0' }}>
			<input type="text"{...rest} />
			{error &&
				<div>
					<hr aria-hidden="true" style={{ borderBottom: '1px solid red' }} />
					<div style={{ color: 'red' }}>{helperText}</div>
				</div>
			}
		</div>)
	}
}

InputComponent.propTypes = {
	helperText: PropTypes.string,
	error: PropTypes.bool
}

InputComponent.defaultProps = {
	helperText: null,
	error: false
}


//	Use this to handle submit - it is passed the synthetic event, values
//	object from the store, isValid, and the validation results.
const handleSubmit = (e, values, isValid, validationResults) => {
	/* eslint-disable no-console */
	if (isValid) {
		console.log('Valid, so we can save here', values)
	} else {
		console.log('Invalid, so we won\'t save', values, validationResults)
	}
}

//	Our main component
class Formtest extends Component {
	constructor(props) {
		super(props)
		// this.handleSubmit = this.handleSubmit.bind(this)

		const me = this
		//	Optionally set initial values of the store here
		this.store = new Store({
			dob: new Date(),
			inputty: 'hello',
			datty: 'world',
			emailAddress: 'test@example.com',
			firstName: 'Test',
			mobile: '0407755577',
			thingy: 'yes'
		},
		() => {
			/* eslint-disable no-underscore-dangle */
			if (me._isMounted) {
				me.forceUpdate()
			}
		})
	}

	componentDidMount() {
		/* eslint-disable no-underscore-dangle */
		this._isMounted = true
	}

	componentWillUnmount() {
		this._isMounted = false
	}

	render() {
		return (
			<div className="route route__signup">
				<h1>Form test</h1>

				<div className={styles.data}>
					<h2>Data model</h2>
					<pre>{JSON.stringify(this.store.get(), null, 4)}</pre>
				</div>

				<Form onSubmit={handleSubmit} debug store={this.store}>
					<span>Hello</span><span>Dude</span>

					<div>
						{/* TODO: implement date picker */}
						{/* <Field
							component={DatePicker}
							label="Date of birth"
							name="dob"
							store={this.store}
						/> */}
					</div>

					<div>
						<Field
							component={Select}
							label="Frequency"
							name="frequency"
						>
							<MenuItem value={1}>Never</MenuItem>
							<MenuItem value={2}>Every Night</MenuItem>
							<MenuItem value={3}>Weeknights</MenuItem>
							<MenuItem value={4}>Weekends</MenuItem>
							<MenuItem value={5}>Weekly</MenuItem>
						</Field>
					</div>

					<div>
						<Field
							component={InputComponent}
							name="inputty"
							value={this.store.get('inputty')}
							validate={validations.inputty}
						/>
					</div>

					<div>
						<Field
							component="input"
							debug
							name="datty"
							supportsHelperText={false}
						/>
					</div>

					<div>
						{/* TODO: implement radio */}
						{/* use the onChange event of the radio button group to get the value */}
						{/* <RadioGroup
							name="shipSpeed"
							validate={validations.shipSpeed}
							onChange={this.store.setBinder('shipSpeed')}
							label="Ship speed"
						>
							<Radio
								name=""
								value="fast"
								label="Fast"
							/>
							<Radio
								value="slow"
								label="Slow"
							/>
						</RadioGroup> */}
					</div>

					<div>
						{/* Basic email field with validation */}
						<Field
							name="emailAddress"
							placeholder="Email address"
							component={TextField}
							validate={validations.emailAddress}
						/>
					</div>
					{/* A field with length validation */}
					<div>
						<Field
							name="firstName"
							placeholder="First name"
							component={TextField}
							/* You can also validate in-line */
							validate={{
								presence: true,
								length: {
									minimum: 2
								}
							}}
						/>
					</div>
					{/* A field with no validation */}
					<div>
						<Field
							name="lastName"
							placeholder="Last name"
							component={TextField}
						/>
					</div>
					{/* A field with custom numeric length */}
					<div>
						<Field
							name="mobile"
							placeholder="Mobile"
							component={TextField}
							validate={validations.mobile}
						/>
					</div>

					{/* A field nested inside a bunch of other fields */}
					<span>
						<span>Before</span>
						<span>
							<span>
								<Field
									name="thingy"
									placeholder="Thingy"
									component={TextField}
								/>
							</span>
							<span>After</span>
						</span>
					</span>

					<div>
						<RButton type="submit" label="Save" />
					</div>
				</Form>

			</div>
		)
	}
}

export default Formtest
