var autoprefixer = require('autoprefixer'),
	path = require('path'),
	webpack = require('webpack'),
	combineLoaders = require('webpack-combine-loaders'),
	HtmlWebpackPlugin = require('html-webpack-plugin'),
	WebpackShellPlugin = require('webpack-shell-plugin');

module.exports = {
	devtool: 'source-map',
	entry: [
		'webpack-dev-server/client?http://local.test:8884',
		'webpack/hot/only-dev-server',
		'./examples/index.js'
	],
	module: {
		rules: [
			//  Ref: https://github.com/webpack/webpack/issues/2168
			{
				test: /node_modules\/JSONStream\/index\.js$/,
				loaders: ['shebang-loader']
			},
			{
				test: /\.(woff|woff2|eot|ttf|svg)$/,
				loader: 'file-loader?name=dist/fonts/roboto/[name].[ext]'
			},
			{
				test: /\.jsx?$/,
				exclude: /node_modules/,
				loader: 'react-hot-loader/webpack!babel-loader'
			},
			{
				test: /\.js$/,
				exclude: /node_modules/,
				loader: 'eslint-loader',
				options: {
					'env': {
						'browser': true,
						'node': true,
						'jasmine': true
					},
					'fix': true
				}
			},

			// "postcss" loader applies autoprefixer to our CSS.
			// "css" loader resolves paths in CSS and adds assets as dependencies.
			// "style" loader turns CSS into JS modules that inject <style> tags.
			// In production, we use a plugin to extract that CSS to a file, but
			// in development "style" loader enables hot editing of CSS.
			{
				test: /\.css$/,
				use: [
					require.resolve('style-loader'),
					{
						loader: require.resolve('css-loader'),
						options: {
							importLoaders: 1,
							sourceMap: true
						}
					},
					{
						loader: require.resolve('postcss-loader'),
						options: {
							ident: 'postcss', // https://webpack.js.org/guides/migrating/#complex-options
							plugins: () => [
								require('postcss-flexbugs-fixes'),
								autoprefixer({
									browsers: [
										'>1%',
										'last 4 versions',
										'Firefox ESR',
										'not ie < 9', // React doesn't support IE8 anyway
									],
									flexbox: 'no-2009',
								}),
							],
						},
					},
				],
			}, {
				test: /\.icss$/,
				include: [path.join(__dirname, './')],
				loader: combineLoaders([
					{
						//loader: 'css-loader',
						loader: 'style-loader!css-loader?sourceMap&modules&importLoaders=1&localIdentName=[name]__[local]___[hash:base64:5]',
						query: {
							modules: true,
							localIdentName: '[name]__[local]___[hash:base64:5]'
						},
						options: {
							sourceMap: true
						}
					}
				])
			}
		]
	},
	plugins: [
		//	Create the output HTML file
		new HtmlWebpackPlugin({
			template: './examples/html.ejs'
		})
	],
	resolve: {
		extensions: ['*', '.js', '.jsx']
	},
	output: {
		path: __dirname + '/../dist',
		publicPath: '/',
		filename: 'bundle.js'
	},
	devServer: {
		overlay: true,
		contentBase: './',
		//	Ref: https://github.com/webpack/webpack-dev-server/issues/147#issuecomment-298816237
		host: "0.0.0.0",
		port: 8884,
		disableHostCheck: true,
		hot: true
	}
};